#################################################################
#                                                               #
# Wilfred                                                       #
# Copyright (C) 2020-2022, Vilhelm Prytz, <vilhelm@prytznet.se> #
#                                                               #
# Licensed under the terms of the MIT license, see LICENSE.     #
# https://github.com/wilfred-dev/wilfred                        #
#                                                               #
#################################################################

import threading


class KeyboardThread(threading.Thread):
    def __init__(self, input_callback, params):
        self._running = True
        self.input_callback = input_callback
        self.params = params

        super(KeyboardThread, self).__init__(name="wilfred-console-input", daemon=True)

        self.start()

    def run(self):
        while self._running:
            try:
                self.input_callback(input(), self.params)
            except Exception:
                self._running = False



#################################################################
#                                                               #
# Wilfred                                                       #
# Copyright (C) 2020-2022, Vilhelm Prytz, <vilhelm@prytznet.se> #
#                                                               #
# Licensed under the terms of the MIT license, see LICENSE.     #
# https://github.com/wilfred-dev/wilfred                        #
#                                                               #
#################################################################

from functools import wraps

from wilfred.message_handler import error
from wilfred.api.config_parser import Config, NoConfiguration

config = Config()

try:
    config.read()
except NoConfiguration:
    pass


def configuration_present(f):
    @wraps(f)
    def decorated_function(*args, **kwargs):
        if not config.configuration:
            error("Wilfred has not been configured", exit_code=1)
        return f(*args, **kwargs)

    return decorated_function



#################################################################
#                                                               #
# Wilfred                                                       #
# Copyright (C) 2020-2022, Vilhelm Prytz, <vilhelm@prytznet.se> #
#                                                               #
# Licensed under the terms of the MIT license, see LICENSE.     #
# https://github.com/wilfred-dev/wilfred                        #
#                                                               #
#################################################################

# use "0.0.0.dev0" to indicate incremental commit build
# specify version "0.3.0" to indicate standard release
# "commit_date" should be replaced upon building
version = "0.10.1"
commit_hash = "cfa76bca4e0520c98e169d3246411367ab5e42a8"
commit_date = "2022-05-08"
